@@ -1,5 +1,7 @@
 from hellosign_python_sdk.utils.request import HSRequest
-from hellosign_python_sdk.utils.exception import *
+from hellosign_python_sdk.utils.exception import HSException, InvalidEmail
+from hellosign_python_sdk.utils.exception import EmptyPassword, NoAuthMethod
+from hellosign_python_sdk.utils.exception import HTTPError
 from hellosign_python_sdk.resource.account import Account
 from hellosign_python_sdk.resource.signature_request import SignatureRequest
 from hellosign_python_sdk.resource.reusable_form import ReusableForm
@@ -44,8 +46,8 @@ class HSClient(object):
     EMBEDDED_OBJECT_GET_URL = API_URL + '/embedded/sign_url/'
 
     UNCLAIMED_DRAFT_CREATE_URL = API_URL + '/unclaimed_draft/create'
-    UNCLAIMED_DRAFT_CREATE_EMBEDDED_URL = API_URL + "/unclaimed_draft/create_embedded";
-
+    UNCLAIMED_DRAFT_CREATE_EMBEDDED_URL = API_URL + \
+        '/unclaimed_draft/create_embedded'
 
     REUSABLE_FORM_GET_URL = API_URL + '/reusable_form/'
     REUSABLE_FORM_GET_LIST_URL = API_URL + '/reusable_form/list'
@@ -94,11 +96,11 @@ class HSClient(object):
 
         """
 
-        if email is None:
+        if not email:
             raise InvalidEmail("Email cannot be empty")
         elif not utils.is_email(email):
             raise InvalidEmail("Email is not valid")
-        if password is None:
+        if not password:
             raise EmptyPassword("Password cannot be empty")
         request = HSRequest(self.auth)
         response = request.post(self.ACCOUNT_CREATE_URL, {
@@ -642,16 +644,13 @@ class HSClient(object):
             name (str): The name of your Team
 
         Returns:
-            True if the Team is updated successfully, False otherwise
+            A Team object of the updated Team
 
         """
 
         request = HSRequest(self.auth)
-        try:
-            request.post(self.TEAM_UPDATE_URL, {"name": name})
-        except HTTPError:
-            return False
-        return True
+        response = request.post(self.TEAM_UPDATE_URL, {"name": name})
+        return Team(response["team"])
 
     def destroy_team(self):
         """Delete your Team
@@ -727,7 +726,6 @@ class HSClient(object):
         response = request.get(self.EMBEDDED_OBJECT_GET_URL + signature_id)
         return Embedded(response["embedded"])
 
-    # RECOMMEND: no title?
     def create_unclaimed_draft(
             self, test_mode="0", client_id=None, is_for_embedded_signing="0",
             requester_email_address=None,
@@ -1114,8 +1112,10 @@ class HSClient(object):
 
         """
 
-        if email_address is None and account_id is None:
+        if not email_address and not account_id:
             raise HSException("No email address or account_id specified")
+        elif email_address and not utils.is_email(email_address):
+            raise InvalidEmail("Email is not valid")
         request = HSRequest(self.auth)
         data = {}
         if account_id is not None:
@@ -1141,16 +1141,16 @@ class HSClient(object):
 
         """
 
-        if email_address is None and account_id is None:
+        if not email_address and not account_id:
             raise HSException("No email address or account_id specified")
+        elif email_address and not utils.is_email(email_address):
+            raise InvalidEmail("Email is not valid")
         request = HSRequest(self.auth)
         data = {}
         if account_id is not None:
             data = {"account_id": account_id}
         else:
             data = {"email_address": email_address}
-        try:
-            request.post(url, data)
-        except HTTPError:
-            return False
-        return True
+
+        response = request.post(url, data)
+        return Team(response["team"])
