@@ -1,5 +1,8 @@
 from hsclient import HSClient
 from utils.hsaccesstokenauth import HSAccessTokenAuth
+from resource.resource import Resource
+from utils.request import HSRequest
+import requests
 # from hellosign_python_sdk.resource.unclaimed_draft import UnclaimedDraft
 
 
@@ -119,6 +122,11 @@ client = HSClient(api_key="a57f10309a04482499e49782b3c0c6f43641780970c2c1d02451c
 
 # Test oauth
 
-a =  client.get_oauth_data("369c76ae6185f3b7", "6a8949c799991e12dac70cb135095680", "a97d141f743a64e598d4baebdf18dc7a", "demo")
-oauth = HSAccessTokenAuth(a['access_token'], a['token_type'], a['refresh_token'], a['expires_in'], a['state'])
-print oauth
\ No newline at end of file
+# a =  client.get_oauth_data("369c76ae6185f3b7", "6a8949c799991e12dac70cb135095680", "a97d141f743a64e598d4baebdf18dc7a", "demo")
+# oauth = HSAccessTokenAuth(a['access_token'], a['token_type'], a['refresh_token'], a['expires_in'], a['state'])
+# print oauth
+auth = HSAccessTokenAuth(access_token="at_test",
+                                 access_token_type="att_test")
+request = HSRequest(auth)
+response = request.get(url='http://httpbin.org/headers')
+print response['headers']
