@@ -12,7 +12,7 @@ def is_email(email):
 
     """
 
-    pattern = '[\.\w]{1,}[@]\w+[.]\w+'
+    pattern = '[\.\+\-\w]{1,}[@]\w+[.]\w+'
     if re.match(pattern, email):
         return True
     else:
